@@ -9,7 +9,8 @@ from typing import Any, Container, DefaultDict, Dict, List, Set, Union
 import httpx
 import yaml
 from github import Github
-from pydantic import BaseModel, BaseSettings, SecretStr
+from pydantic import BaseModel, SecretStr
+from pydantic_settings import BaseSettings
 
 github_graphql_url = "https://api.github.com/graphql"
 questions_category_id = "MDE4OkRpc2N1c3Npb25DYXRlZ29yeTMyMDAxNDM0"
@@ -57,38 +58,6 @@ query Q($after: String, $category_id: ID) {
 }
 """
 
-issues_query = """
-query Q($after: String) {
-  repository(name: "fastapi", owner: "tiangolo") {
-    issues(first: 100, after: $after) {
-      edges {
-        cursor
-        node {
-          number
-          author {
-            login
-            avatarUrl
-            url
-          }
-          title
-          createdAt
-          state
-          comments(first: 100) {
-            nodes {
-              createdAt
-              author {
-                login
-                avatarUrl
-                url
-              }
-            }
-          }
-        }
-      }
-    }
-  }
-}
-"""
 
 prs_query = """
 query Q($after: String) {
@@ -175,7 +144,7 @@ class Author(BaseModel):
     url: str
 
 
-# Issues and Discussions
+# Discussions
 
 
 class CommentsNode(BaseModel):
@@ -199,15 +168,6 @@ class DiscussionsComments(BaseModel):
     nodes: List[DiscussionsCommentsNode]
 
 
-class IssuesNode(BaseModel):
-    number: int
-    author: Union[Author, None] = None
-    title: str
-    createdAt: datetime
-    state: str
-    comments: Comments
-
-
 class DiscussionsNode(BaseModel):
     number: int
     author: Union[Author, None] = None
@@ -216,44 +176,23 @@ class DiscussionsNode(BaseModel):
     comments: DiscussionsComments
 
 
-class IssuesEdge(BaseModel):
-    cursor: str
-    node: IssuesNode
-
-
 class DiscussionsEdge(BaseModel):
     cursor: str
     node: DiscussionsNode
 
 
-class Issues(BaseModel):
-    edges: List[IssuesEdge]
-
-
 class Discussions(BaseModel):
     edges: List[DiscussionsEdge]
 
 
-class IssuesRepository(BaseModel):
-    issues: Issues
-
-
 class DiscussionsRepository(BaseModel):
     discussions: Discussions
 
 
-class IssuesResponseData(BaseModel):
-    repository: IssuesRepository
-
-
 class DiscussionsResponseData(BaseModel):
     repository: DiscussionsRepository
 
 
-class IssuesResponse(BaseModel):
-    data: IssuesResponseData
-
-
 class DiscussionsResponse(BaseModel):
     data: DiscussionsResponseData
 
@@ -382,17 +321,12 @@ def get_graphql_response(
     data = response.json()
     if "errors" in data:
         logging.error(f"Errors in response, after: {after}, category_id: {category_id}")
+        logging.error(data["errors"])
         logging.error(response.text)
         raise RuntimeError(response.text)
     return data
 
 
-def get_graphql_issue_edges(*, settings: Settings, after: Union[str, None] = None):
-    data = get_graphql_response(settings=settings, query=issues_query, after=after)
-    graphql_response = IssuesResponse.parse_obj(data)
-    return graphql_response.data.repository.issues.edges
-
-
 def get_graphql_question_discussion_edges(
     *,
     settings: Settings,
@@ -404,59 +338,32 @@ def get_graphql_question_discussion_edges(
         after=after,
         category_id=questions_category_id,
     )
-    graphql_response = DiscussionsResponse.parse_obj(data)
+    graphql_response = DiscussionsResponse.model_validate(data)
     return graphql_response.data.repository.discussions.edges
 
 
 def get_graphql_pr_edges(*, settings: Settings, after: Union[str, None] = None):
     data = get_graphql_response(settings=settings, query=prs_query, after=after)
-    graphql_response = PRsResponse.parse_obj(data)
+    graphql_response = PRsResponse.model_validate(data)
     return graphql_response.data.repository.pullRequests.edges
 
 
 def get_graphql_sponsor_edges(*, settings: Settings, after: Union[str, None] = None):
     data = get_graphql_response(settings=settings, query=sponsors_query, after=after)
-    graphql_response = SponsorsResponse.parse_obj(data)
+    graphql_response = SponsorsResponse.model_validate(data)
     return graphql_response.data.user.sponsorshipsAsMaintainer.edges
 
 
-def get_issues_experts(settings: Settings):
-    issue_nodes: List[IssuesNode] = []
-    issue_edges = get_graphql_issue_edges(settings=settings)
-
-    while issue_edges:
-        for edge in issue_edges:
-            issue_nodes.append(edge.node)
-        last_edge = issue_edges[-1]
-        issue_edges = get_graphql_issue_edges(settings=settings, after=last_edge.cursor)
-
-    commentors = Counter()
-    last_month_commentors = Counter()
-    authors: Dict[str, Author] = {}
-
-    now = datetime.now(tz=timezone.utc)
-    one_month_ago = now - timedelta(days=30)
-
-    for issue in issue_nodes:
-        issue_author_name = None
-        if issue.author:
-            authors[issue.author.login] = issue.author
-            issue_author_name = issue.author.login
-        issue_commentors = set()
-        for comment in issue.comments.nodes:
-            if comment.author:
-                authors[comment.author.login] = comment.author
-                if comment.author.login != issue_author_name:
-                    issue_commentors.add(comment.author.login)
-        for author_name in issue_commentors:
-            commentors[author_name] += 1
-            if issue.createdAt > one_month_ago:
-                last_month_commentors[author_name] += 1
-
-    return commentors, last_month_commentors, authors
+class DiscussionExpertsResults(BaseModel):
+    commenters: Counter
+    last_month_commenters: Counter
+    three_months_commenters: Counter
+    six_months_commenters: Counter
+    one_year_commenters: Counter
+    authors: Dict[str, Author]
 
 
-def get_discussions_experts(settings: Settings):
+def get_discussion_nodes(settings: Settings) -> List[DiscussionsNode]:
     discussion_nodes: List[DiscussionsNode] = []
     discussion_edges = get_graphql_question_discussion_edges(settings=settings)
 
@@ -467,61 +374,73 @@ def get_discussions_experts(settings: Settings):
         discussion_edges = get_graphql_question_discussion_edges(
             settings=settings, after=last_edge.cursor
         )
+    return discussion_nodes
 
-    commentors = Counter()
-    last_month_commentors = Counter()
+
+def get_discussions_experts(
+    discussion_nodes: List[DiscussionsNode],
+) -> DiscussionExpertsResults:
+    commenters = Counter()
+    last_month_commenters = Counter()
+    three_months_commenters = Counter()
+    six_months_commenters = Counter()
+    one_year_commenters = Counter()
     authors: Dict[str, Author] = {}
 
     now = datetime.now(tz=timezone.utc)
     one_month_ago = now - timedelta(days=30)
+    three_months_ago = now - timedelta(days=90)
+    six_months_ago = now - timedelta(days=180)
+    one_year_ago = now - timedelta(days=365)
 
     for discussion in discussion_nodes:
         discussion_author_name = None
         if discussion.author:
             authors[discussion.author.login] = discussion.author
             discussion_author_name = discussion.author.login
-        discussion_commentors = set()
+        discussion_commentors: dict[str, datetime] = {}
         for comment in discussion.comments.nodes:
             if comment.author:
                 authors[comment.author.login] = comment.author
                 if comment.author.login != discussion_author_name:
-                    discussion_commentors.add(comment.author.login)
+                    author_time = discussion_commentors.get(
+                        comment.author.login, comment.createdAt
+                    )
+                    discussion_commentors[comment.author.login] = max(
+                        author_time, comment.createdAt
+                    )
             for reply in comment.replies.nodes:
                 if reply.author:
                     authors[reply.author.login] = reply.author
                     if reply.author.login != discussion_author_name:
-                        discussion_commentors.add(reply.author.login)
-        for author_name in discussion_commentors:
-            commentors[author_name] += 1
-            if discussion.createdAt > one_month_ago:
-                last_month_commentors[author_name] += 1
-    return commentors, last_month_commentors, authors
+                        author_time = discussion_commentors.get(
+                            reply.author.login, reply.createdAt
+                        )
+                        discussion_commentors[reply.author.login] = max(
+                            author_time, reply.createdAt
+                        )
+        for author_name, author_time in discussion_commentors.items():
+            commenters[author_name] += 1
+            if author_time > one_month_ago:
+                last_month_commenters[author_name] += 1
+            if author_time > three_months_ago:
+                three_months_commenters[author_name] += 1
+            if author_time > six_months_ago:
+                six_months_commenters[author_name] += 1
+            if author_time > one_year_ago:
+                one_year_commenters[author_name] += 1
+    discussion_experts_results = DiscussionExpertsResults(
+        authors=authors,
+        commenters=commenters,
+        last_month_commenters=last_month_commenters,
+        three_months_commenters=three_months_commenters,
+        six_months_commenters=six_months_commenters,
+        one_year_commenters=one_year_commenters,
+    )
+    return discussion_experts_results
 
 
-def get_experts(settings: Settings):
-    # Migrated to only use GitHub Discussions
-    # (
-    #     issues_commentors,
-    #     issues_last_month_commentors,
-    #     issues_authors,
-    # ) = get_issues_experts(settings=settings)
-    (
-        discussions_commentors,
-        discussions_last_month_commentors,
-        discussions_authors,
-    ) = get_discussions_experts(settings=settings)
-    # commentors = issues_commentors + discussions_commentors
-    commentors = discussions_commentors
-    # last_month_commentors = (
-    #     issues_last_month_commentors + discussions_last_month_commentors
-    # )
-    last_month_commentors = discussions_last_month_commentors
-    # authors = {**issues_authors, **discussions_authors}
-    authors = {**discussions_authors}
-    return commentors, last_month_commentors, authors
-
-
-def get_contributors(settings: Settings):
+def get_pr_nodes(settings: Settings) -> List[PullRequestNode]:
     pr_nodes: List[PullRequestNode] = []
     pr_edges = get_graphql_pr_edges(settings=settings)
 
@@ -530,10 +449,22 @@ def get_contributors(settings: Settings):
             pr_nodes.append(edge.node)
         last_edge = pr_edges[-1]
         pr_edges = get_graphql_pr_edges(settings=settings, after=last_edge.cursor)
+    return pr_nodes
 
+
+class ContributorsResults(BaseModel):
+    contributors: Counter
+    commenters: Counter
+    reviewers: Counter
+    translation_reviewers: Counter
+    authors: Dict[str, Author]
+
+
+def get_contributors(pr_nodes: List[PullRequestNode]) -> ContributorsResults:
     contributors = Counter()
-    commentors = Counter()
+    commenters = Counter()
     reviewers = Counter()
+    translation_reviewers = Counter()
     authors: Dict[str, Author] = {}
 
     for pr in pr_nodes:
@@ -550,16 +481,26 @@ def get_contributors(settings: Settings):
                     continue
                 pr_commentors.add(comment.author.login)
         for author_name in pr_commentors:
-            commentors[author_name] += 1
+            commenters[author_name] += 1
         for review in pr.reviews.nodes:
             if review.author:
                 authors[review.author.login] = review.author
                 pr_reviewers.add(review.author.login)
+                for label in pr.labels.nodes:
+                    if label.name == "lang-all":
+                        translation_reviewers[review.author.login] += 1
+                        break
         for reviewer in pr_reviewers:
             reviewers[reviewer] += 1
         if pr.state == "MERGED" and pr.author:
             contributors[pr.author.login] += 1
-    return contributors, commentors, reviewers, authors
+    return ContributorsResults(
+        contributors=contributors,
+        commenters=commenters,
+        reviewers=reviewers,
+        translation_reviewers=translation_reviewers,
+        authors=authors,
+    )
 
 
 def get_individual_sponsors(settings: Settings):
@@ -583,19 +524,19 @@ def get_individual_sponsors(settings: Settings):
 def get_top_users(
     *,
     counter: Counter,
-    min_count: int,
     authors: Dict[str, Author],
     skip_users: Container[str],
+    min_count: int = 2,
 ):
     users = []
-    for commentor, count in counter.most_common(50):
-        if commentor in skip_users:
+    for commenter, count in counter.most_common(50):
+        if commenter in skip_users:
             continue
         if count >= min_count:
-            author = authors[commentor]
+            author = authors[commenter]
             users.append(
                 {
-                    "login": commentor,
+                    "login": commenter,
                     "count": count,
                     "avatarUrl": author.avatarUrl,
                     "url": author.url,
@@ -607,16 +548,14 @@ def get_top_users(
 if __name__ == "__main__":
     logging.basicConfig(level=logging.INFO)
     settings = Settings()
-    logging.info(f"Using config: {settings.json()}")
+    logging.info(f"Using config: {settings.model_dump_json()}")
     g = Github(settings.input_token.get_secret_value())
     repo = g.get_repo(settings.github_repository)
-    question_commentors, question_last_month_commentors, question_authors = get_experts(
-        settings=settings
-    )
-    contributors, pr_commentors, reviewers, pr_authors = get_contributors(
-        settings=settings
-    )
-    authors = {**question_authors, **pr_authors}
+    discussion_nodes = get_discussion_nodes(settings=settings)
+    experts_results = get_discussions_experts(discussion_nodes=discussion_nodes)
+    pr_nodes = get_pr_nodes(settings=settings)
+    contributors_results = get_contributors(pr_nodes=pr_nodes)
+    authors = {**experts_results.authors, **contributors_results.authors}
     maintainers_logins = {"tiangolo"}
     bot_names = {"codecov", "github-actions", "pre-commit-ci", "dependabot"}
     maintainers = []
@@ -625,39 +564,51 @@ if __name__ == "__main__":
         maintainers.append(
             {
                 "login": login,
-                "answers": question_commentors[login],
-                "prs": contributors[login],
+                "answers": experts_results.commenters[login],
+                "prs": contributors_results.contributors[login],
                 "avatarUrl": user.avatarUrl,
                 "url": user.url,
             }
         )
 
-    min_count_expert = 10
-    min_count_last_month = 3
-    min_count_contributor = 4
-    min_count_reviewer = 4
     skip_users = maintainers_logins | bot_names
     experts = get_top_users(
-        counter=question_commentors,
-        min_count=min_count_expert,
+        counter=experts_results.commenters,
         authors=authors,
         skip_users=skip_users,
     )
-    last_month_active = get_top_users(
-        counter=question_last_month_commentors,
-        min_count=min_count_last_month,
+    last_month_experts = get_top_users(
+        counter=experts_results.last_month_commenters,
+        authors=authors,
+        skip_users=skip_users,
+    )
+    three_months_experts = get_top_users(
+        counter=experts_results.three_months_commenters,
+        authors=authors,
+        skip_users=skip_users,
+    )
+    six_months_experts = get_top_users(
+        counter=experts_results.six_months_commenters,
+        authors=authors,
+        skip_users=skip_users,
+    )
+    one_year_experts = get_top_users(
+        counter=experts_results.one_year_commenters,
         authors=authors,
         skip_users=skip_users,
     )
     top_contributors = get_top_users(
-        counter=contributors,
-        min_count=min_count_contributor,
+        counter=contributors_results.contributors,
         authors=authors,
         skip_users=skip_users,
     )
     top_reviewers = get_top_users(
-        counter=reviewers,
-        min_count=min_count_reviewer,
+        counter=contributors_results.reviewers,
+        authors=authors,
+        skip_users=skip_users,
+    )
+    top_translations_reviewers = get_top_users(
+        counter=contributors_results.translation_reviewers,
         authors=authors,
         skip_users=skip_users,
     )
@@ -677,13 +628,19 @@ if __name__ == "__main__":
     people = {
         "maintainers": maintainers,
         "experts": experts,
-        "last_month_active": last_month_active,
+        "last_month_experts": last_month_experts,
+        "three_months_experts": three_months_experts,
+        "six_months_experts": six_months_experts,
+        "one_year_experts": one_year_experts,
         "top_contributors": top_contributors,
         "top_reviewers": top_reviewers,
+        "top_translations_reviewers": top_translations_reviewers,
     }
     github_sponsors = {
         "sponsors": sponsors,
     }
+    # For local development
+    # people_path = Path("../../../../docs/en/data/people.yml")
     people_path = Path("./docs/en/data/people.yml")
     github_sponsors_path = Path("./docs/en/data/github_sponsors.yml")
     people_old_content = people_path.read_text(encoding="utf-8")
