@@ -1,19 +1,19 @@
 from fastapi.testclient import TestClient
 
-from . import config, main
+from .config import Settings
+from .main import app, get_settings
 
-client = TestClient(main.app)
+client = TestClient(app)
 
 
 def get_settings_override():
-    return config.Settings(admin_email="testing_admin@example.com")
+    return Settings(admin_email="testing_admin@example.com")
 
 
-main.app.dependency_overrides[main.get_settings] = get_settings_override
+app.dependency_overrides[get_settings] = get_settings_override
 
 
 def test_app():
-
     response = client.get("/info")
     data = response.json()
     assert data == {
