@@ -1,4 +1,5 @@
 import pytest
+from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 
 from ...utils import needs_py310
@@ -12,42 +13,59 @@ def get_client():
     return client
 
 
-regex_error = {
-    "detail": [
-        {
-            "ctx": {"pattern": "^fixedquery$"},
-            "loc": ["query", "item-query"],
-            "msg": 'string does not match regex "^fixedquery$"',
-            "type": "value_error.str.regex",
-        }
-    ]
-}
+@needs_py310
+def test_query_params_str_validations_no_query(client: TestClient):
+    response = client.get("/items/")
+    assert response.status_code == 200
+    assert response.json() == {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}]}
 
 
 @needs_py310
-@pytest.mark.parametrize(
-    "q_name,q,expected_status,expected_response",
-    [
-        (None, None, 200, {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}]}),
-        (
-            "item-query",
-            "fixedquery",
-            200,
-            {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}], "q": "fixedquery"},
-        ),
-        ("q", "fixedquery", 200, {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}]}),
-        ("item-query", "nonregexquery", 422, regex_error),
-    ],
-)
-def test_query_params_str_validations(
-    q_name, q, expected_status, expected_response, client: TestClient
-):
-    url = "/items/"
-    if q_name and q:
-        url = f"{url}?{q_name}={q}"
-    response = client.get(url)
-    assert response.status_code == expected_status
-    assert response.json() == expected_response
+def test_query_params_str_validations_item_query_fixedquery(client: TestClient):
+    response = client.get("/items/", params={"item-query": "fixedquery"})
+    assert response.status_code == 200
+    assert response.json() == {
+        "items": [{"item_id": "Foo"}, {"item_id": "Bar"}],
+        "q": "fixedquery",
+    }
+
+
+@needs_py310
+def test_query_params_str_validations_q_fixedquery(client: TestClient):
+    response = client.get("/items/", params={"q": "fixedquery"})
+    assert response.status_code == 200
+    assert response.json() == {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}]}
+
+
+@needs_py310
+def test_query_params_str_validations_item_query_nonregexquery(client: TestClient):
+    response = client.get("/items/", params={"item-query": "nonregexquery"})
+    assert response.status_code == 422
+    assert response.json() == IsDict(
+        {
+            "detail": [
+                {
+                    "type": "string_pattern_mismatch",
+                    "loc": ["query", "item-query"],
+                    "msg": "String should match pattern '^fixedquery$'",
+                    "input": "nonregexquery",
+                    "ctx": {"pattern": "^fixedquery$"},
+                }
+            ]
+        }
+    ) | IsDict(
+        # TODO: remove when deprecating Pydantic v1
+        {
+            "detail": [
+                {
+                    "ctx": {"pattern": "^fixedquery$"},
+                    "loc": ["query", "item-query"],
+                    "msg": 'string does not match regex "^fixedquery$"',
+                    "type": "value_error.str.regex",
+                }
+            ]
+        }
+    )
 
 
 @needs_py310
@@ -83,14 +101,32 @@ def test_openapi_schema(client: TestClient):
                             "description": "Query string for the items to search in the database that have a good match",
                             "required": False,
                             "deprecated": True,
-                            "schema": {
-                                "title": "Query string",
-                                "maxLength": 50,
-                                "minLength": 3,
-                                "pattern": "^fixedquery$",
-                                "type": "string",
-                                "description": "Query string for the items to search in the database that have a good match",
-                            },
+                            "schema": IsDict(
+                                {
+                                    "anyOf": [
+                                        {
+                                            "type": "string",
+                                            "minLength": 3,
+                                            "maxLength": 50,
+                                            "pattern": "^fixedquery$",
+                                        },
+                                        {"type": "null"},
+                                    ],
+                                    "title": "Query string",
+                                    "description": "Query string for the items to search in the database that have a good match",
+                                }
+                            )
+                            | IsDict(
+                                # TODO: remove when deprecating Pydantic v1
+                                {
+                                    "title": "Query string",
+                                    "maxLength": 50,
+                                    "minLength": 3,
+                                    "pattern": "^fixedquery$",
+                                    "type": "string",
+                                    "description": "Query string for the items to search in the database that have a good match",
+                                }
+                            ),
                             "name": "item-query",
                             "in": "query",
                         }
