@@ -3,8 +3,11 @@ import os
 from pathlib import Path
 
 import pytest
+from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 
+from ...utils import needs_pydanticv1
+
 
 @pytest.fixture(scope="module")
 def client(tmp_path_factory: pytest.TempPathFactory):
@@ -26,6 +29,8 @@ def client(tmp_path_factory: pytest.TempPathFactory):
     os.chdir(cwd)
 
 
+# TODO: pv2 add version with Pydantic v2
+@needs_pydanticv1
 def test_create_user(client):
     test_user = {"email": "johndoe@example.com", "password": "secret"}
     response = client.post("/users/", json=test_user)
@@ -37,6 +42,8 @@ def test_create_user(client):
     assert response.status_code == 400, response.text
 
 
+# TODO: pv2 add version with Pydantic v2
+@needs_pydanticv1
 def test_get_user(client):
     response = client.get("/users/1")
     assert response.status_code == 200, response.text
@@ -45,11 +52,15 @@ def test_get_user(client):
     assert "id" in data
 
 
-def test_inexistent_user(client):
+# TODO: pv2 add version with Pydantic v2
+@needs_pydanticv1
+def test_nonexistent_user(client):
     response = client.get("/users/999")
     assert response.status_code == 404, response.text
 
 
+# TODO: pv2 add version with Pydantic v2
+@needs_pydanticv1
 def test_get_users(client):
     response = client.get("/users/")
     assert response.status_code == 200, response.text
@@ -58,6 +69,8 @@ def test_get_users(client):
     assert "id" in data[0]
 
 
+# TODO: pv2 add Pydantic v2 version
+@needs_pydanticv1
 def test_create_item(client):
     item = {"title": "Foo", "description": "Something that fights"}
     response = client.post("/users/1/items/", json=item)
@@ -75,6 +88,8 @@ def test_create_item(client):
     assert item_to_check["description"] == item["description"]
 
 
+# TODO: pv2 add Pydantic v2 version
+@needs_pydanticv1
 def test_read_items(client):
     response = client.get("/items/")
     assert response.status_code == 200, response.text
@@ -85,7 +100,9 @@ def test_read_items(client):
     assert "description" in first_item
 
 
-def test_openapi_schema(client):
+# TODO: pv2 add version with Pydantic v2
+@needs_pydanticv1
+def test_openapi_schema(client: TestClient):
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
     assert response.json() == {
@@ -313,7 +330,16 @@ def test_openapi_schema(client):
                     "type": "object",
                     "properties": {
                         "title": {"title": "Title", "type": "string"},
-                        "description": {"title": "Description", "type": "string"},
+                        "description": IsDict(
+                            {
+                                "title": "Description",
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                            }
+                        )
+                        | IsDict(
+                            # TODO: remove when deprecating Pydantic v1
+                            {"title": "Description", "type": "string"}
+                        ),
                     },
                 },
                 "Item": {
@@ -322,7 +348,16 @@ def test_openapi_schema(client):
                     "type": "object",
                     "properties": {
                         "title": {"title": "Title", "type": "string"},
-                        "description": {"title": "Description", "type": "string"},
+                        "description": IsDict(
+                            {
+                                "title": "Description",
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                            }
+                        )
+                        | IsDict(
+                            # TODO: remove when deprecating Pydantic v1
+                            {"title": "Description", "type": "string"},
+                        ),
                         "id": {"title": "Id", "type": "integer"},
                         "owner_id": {"title": "Owner Id", "type": "integer"},
                     },
